<?php

namespace Drupal\simple_html_mail\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\file\Entity\File;

/**
 * Class HtmlMailSettingsForm.
 */
class HtmlMailSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'simple_html_mail.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'html_mail_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('simple_html_mail.settings');

    $image = $config->get('image');
    $form['image'] = [
      '#type' => 'managed_file',
      '#upload_location' => 'public://html-mail-template',
      '#title' => t('Image'),
      '#upload_validators' => [
        'file_validate_extensions' => ['jpg jpeg png gif'],
        'file_validate_size' => [25600000],
      ],
      '#default_value' => isset($image) ? $image : '',
      '#description' => t('The logo image to display in email'),
      '#required' => TRUE,
    ];

    $form['header_slogan'] = [
      '#title' => $this->t('Header slogan text'),
      '#type' => 'textfield',
      '#default_value' => $config->get('header_slogan'),
    ];

    $form['footer_text'] = [
      '#title' => $this->t('Footer text'),
      '#type' => 'textfield',
      '#default_value' => $config->get('footer_text'),
    ];

    $form['mail_ids'] = [
      '#title' => $this->t('Mail IDs'),
      '#type' => 'textarea',
      '#default_value' => $config->get('mail_ids'),
      '#description' => $this->t('Enter comma separated e-mail ids for e-mails that you want to go through HTML mail template.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save image as permanent.
    $image = $form_state->getValue('image');
    if ($image != $this->config('simple_html_mail.settings')->get('image')) {
      if (!empty($image[0])) {
        $file = File::load($image[0]);
        $file->setPermanent();
        $file->save();
      }
    }

    $this->config('simple_html_mail.settings')
      ->set('mail_ids', $form_state->getValue('mail_ids'))
      ->set('image', $form_state->getValue('image'))
      ->set('header_slogan', $form_state->getValue('header_slogan'))
      ->set('footer_text', $form_state->getValue('footer_text'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
